@@ -8,9 +8,8 @@
 (put 'cd-tool 'custom-loads '(cd-tool))
 (put 'dtk 'custom-loads '(dtk-speak))
 (put 'dtk-unicode 'custom-loads '(dtk-unicode))
-(put 'emacspeak 'custom-loads '(dtk-speak dtk-unicode emacspeak emacspeak-add-log emacspeak-advice emacspeak-alsaplayer emacspeak-aumix emacspeak-bookshare emacspeak-dbus emacspeak-dismal emacspeak-epub emacspeak-erc emacspeak-eshell emacspeak-espn emacspeak-eterm emacspeak-eudc emacspeak-feeds emacspeak-flyspell emacspeak-forms emacspeak-gnus emacspeak-ido emacspeak-ispell emacspeak-jss emacspeak-keymap emacspeak-kite emacspeak-m-player emacspeak-message emacspeak-midge emacspeak-npr emacspeak-nxml emacspeak-ocr emacspeak-pronounce emacspeak-replace emacspeak-setup emacspeak-sounds emacspeak-speak emacspeak-speedbar emacspeak-vm emacspeak-w3 emacspeak-w3m emacspeak-we emacspeak-websearch emacspeak-widget emacspeak-wizards emacspeak-xml-shell emacspeak-xslt sox voice-setup xbacklight))
+(put 'emacspeak 'custom-loads '(dtk-speak dtk-unicode emacspeak emacspeak-add-log emacspeak-advice emacspeak-aumix emacspeak-bookshare emacspeak-dbus emacspeak-dismal emacspeak-epub emacspeak-erc emacspeak-eshell emacspeak-espn emacspeak-eterm emacspeak-eudc emacspeak-feeds emacspeak-flyspell emacspeak-forms emacspeak-gnus emacspeak-ido emacspeak-ispell emacspeak-jss emacspeak-keymap emacspeak-kite emacspeak-m-player emacspeak-maths emacspeak-message emacspeak-midge emacspeak-npr emacspeak-nxml emacspeak-ocr emacspeak-pronounce emacspeak-replace emacspeak-setup emacspeak-sounds emacspeak-speak emacspeak-speedbar emacspeak-vm emacspeak-w3 emacspeak-w3m emacspeak-we emacspeak-websearch emacspeak-widget emacspeak-wizards emacspeak-xml-shell emacspeak-xslt sox voice-setup xbacklight))
 (put 'emacspeak-advice 'custom-loads '(emacspeak-advice))
-(put 'emacspeak-alsaplayer 'custom-loads '(emacspeak-alsaplayer))
 (put 'emacspeak-aumix 'custom-loads '(emacspeak-aumix))
 (put 'emacspeak-bbc 'custom-loads '(emacspeak-bbc))
 (put 'emacspeak-bookshare 'custom-loads '(emacspeak-bookshare))
@@ -37,6 +36,7 @@
 (put 'emacspeak-jabber 'custom-loads '(emacspeak-jabber))
 (put 'emacspeak-librivox 'custom-loads '(emacspeak-librivox))
 (put 'emacspeak-m-player 'custom-loads '(emacspeak-m-player))
+(put 'emacspeak-maths 'custom-loads '(emacspeak-maths))
 (put 'emacspeak-media 'custom-loads '(emacspeak-m-player))
 (put 'emacspeak-message 'custom-loads '(emacspeak-message))
 (put 'emacspeak-midge 'custom-loads '(emacspeak-midge))
@@ -78,6 +78,7 @@
 (put 'tts 'custom-loads '(dtk-speak emacspeak-setup))
 (put 'vm 'custom-loads '(emacspeak-vm))
 (put 'voice-fonts 'custom-loads '(voice-setup))
+(put 'voice-lock 'custom-loads '(voice-setup))
 (put 'w3 'custom-loads '(emacspeak-w3))
 (put 'w3m 'custom-loads '(emacspeak-w3m))
 (put 'widget 'custom-loads '(emacspeak-widget))
