@@ -1,4 +1,4 @@
-;;; emacspeak-ispell.el --- Speech enable Ispell -- Emacs' interactive spell checker
+;;; emacspeak-ispell.el --- Speech enable Ispell -- Emacs' interactive spell checker  -*- lexical-binding: t; -*-
 ;;; $Id$
 ;;; $Author: tv.raman.tv $ 
 ;;; Description:  Emacspeak extension to speech enable flyspell
@@ -95,7 +95,7 @@
 ;;}}}
 ;;{{{  Highlighting the error 
 
-(defun emacspeak-flyspell-highlight-incorrect-word (beg end ignore)
+(defun emacspeak-flyspell-highlight-incorrect-word (beg end _ignore)
   "Put property personality with value
 `voice-animate' from beg to end"
   (declare (special voice-animate))
