@@ -1,4 +1,4 @@
-;;; emacspeak-message.el --- Speech enable Message -- Used to compose news postings and replies
+;;; emacspeak-message.el --- Speech enable Message -- Used to compose news postings and replies  -*- lexical-binding: t; -*-
 ;;; $Id$
 ;;; $Author: tv.raman.tv $ 
 ;;; Description: Emacspeak extensions for posting
@@ -53,7 +53,7 @@
   :group 'message
   :prefix "emacspeak-message-")
 
-(defcustom emacspeak-message-punctuation-mode  'some
+(defcustom emacspeak-message-punctuation-mode  'all
   "Pronunciation mode to use for message buffers."
   :type '(choice
           (const  :tag "Ignore" nil)
