@@ -1,4 +1,4 @@
-;;; emacspeak-paradox.el --- Speech-enable PARADOX
+;;; emacspeak-paradox.el --- Speech-enable PARADOX  -*- lexical-binding: t; -*-
 ;;; $Id: emacspeak-paradox.el 4797 2007-07-16 23:31:22Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Speech-enable PARADOX An Emacs Interface to paradox
@@ -86,7 +86,7 @@
      ((string= state "built-in") (emacspeak-auditory-icon 'mark-object))
      ((string= state "dependency") (emacspeak-auditory-icon 'close-object))
      ((string= state "obsolete") (emacspeak-auditory-icon 'deselect-object))
-     ((string= state "incompat") (emacspeak-auditory-icon 'warn-user))
+     ((string= state "incompat") (emacspeak-auditory-icon 'alert-user))
      (t (emacspeak-auditory-icon 'item)))
     (dtk-speak-and-echo  (concat name ": "desc
                                  stars))))
@@ -105,7 +105,8 @@
 
 (defadvice paradox-menu-execute(around emacspeak pre act comp)
   "Silence messages while installing packages. "
-  (ems-with-messages-silenced ad-do-it))
+  (ems-with-messages-silenced ad-do-it)
+  (emacspeak-speak-message-again))
 
 (loop
  for f in
