@@ -1,4 +1,4 @@
-;;; emacspeak-pianobar.el --- Pandora Radio: Speech-enable PIANOBAR
+;;; emacspeak-pianobar.el --- Pandora Radio: Speech-enable PIANOBAR  -*- lexical-binding: t; -*-
 ;;; $Id: emacspeak-pianobar.el 4797 2007-07-16 23:31:22Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Speech-enable PIANOBAR An Emacs Interface to pianobar
@@ -126,7 +126,7 @@
     (define-key  pianobar-key-map [up] 'emacspeak-pianobar-previous-preset)
     (define-key  pianobar-key-map [down] 'emacspeak-pianobar-next-preset)
     (define-key  pianobar-key-map "," 'emacspeak-pianobar-previous-preset)
-    (define-key  pianobar-key-map [down]".")
+    (define-key  pianobar-key-map "." 'emacspeak-pianobar-next-preset)
     (define-key  pianobar-key-map "<" 'emacspeak-pianobar-previous-preset)
     (define-key  pianobar-key-map">" 'emacspeak-pianobar-next-preset)
     (define-key pianobar-key-map "("
