@@ -1,4 +1,4 @@
-;;; emacspeak-python.el --- Speech enable Python development environment
+;;; emacspeak-python.el --- Speech enable Python development environment  -*- lexical-binding: t; -*-
 ;;; $Id$
 ;;; $Author: tv.raman.tv $
 ;;; Description: Auditory interface to python mode
@@ -67,7 +67,7 @@
                             python-shell-send-string python-shell-send-string-no-output)
  do
  (eval
-  `(defadvice python-shell-send-region (after emacspeak pre act comp)
+  `(defadvice ,f (after emacspeak pre act comp)
      "Provide auditory feedback"
      (when (ems-interactive-p)
        (emacspeak-auditory-icon 'task-done)))))
@@ -78,7 +78,7 @@
   "Provide auditory feedback."
   (when (ems-interactive-p)
     (emacspeak-speak-line)
-    (emacspeak-auditory-icon 'select-object)))
+    (emacspeak-auditory-icon 'right)))
 
 (defadvice  python-indent-dedent-line-backspace (around emacspeak pre act)
   "Speak character you're deleting."
@@ -99,7 +99,7 @@
 (defadvice python-indent-shift-left (after emacspeak pre act comp)
   "Speak number of lines that were shifted"
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'large-movement)
+    (emacspeak-auditory-icon 'left)
     (dtk-speak
      (format "Left shifted block  containing %s lines"
              (count-lines  (region-beginning)
@@ -114,7 +114,7 @@
 (defadvice python-indent-region (after emacspeak pre act comp)
   "Speak number of lines that were shifted"
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'large-movement)
+    (emacspeak-auditory-icon 'right)
     (dtk-speak
      (format "Indented region   containing %s lines"
              (count-lines  (region-beginning)
@@ -139,7 +139,7 @@
      "Provide auditory feedback."
      (when (ems-interactive-p)
        (emacspeak-speak-line)
-       (emacspeak-auditory-icon 'large-movement)))))
+       (emacspeak-auditory-icon 'paragraph)))))
 
 ;;}}}
 (provide 'emacspeak-python)
