@@ -1,4 +1,4 @@
-;;; emacspeak-rpm-spec.el --- Speech enable rpm spec editor
+;;; emacspeak-rpm-spec.el --- Speech enable rpm spec editor  -*- lexical-binding: t; -*-
 ;;; $Id$
 ;;; $Author: tv.raman.tv $
 ;;; Description: Controlling mplayer from emacs 
@@ -143,8 +143,7 @@
                      (replace-regexp-in-string "toggle"
                                                "spec"
                                                toggle)))
-              (emacspeak-auditory-icon
-               (if (eval switch) 'on 'off)))))))
+              (emacspeak-auditory-icon (if (eval switch) 'on 'off)))))))
 
 ;;}}}
 ;;{{{ voice locking 
