@@ -1,4 +1,4 @@
-;;; g-app.el --- Google Client APP methods
+;;; g-app.el --- Google Client APP methods  -*- lexical-binding: t; -*-
 ;;;$Id$
 ;;; $Author: raman $
 ;;; Description:  Google Client App
@@ -57,6 +57,7 @@
 (require 'backquote)
 (require 'g-utils)
 (require 'g-auth)
+(require 'nxml-mode)
 (declaim  (optimize  (safety 0) (speed 3)))
 
 ;;}}}
