@@ -3,13 +3,10 @@
 ;;; Code:
 
 (put 'applications 'custom-loads '(g))
-(put 'g 'custom-loads '(g-auth g-utils gblogger gdocs gfeeds gmaps gphoto gskeleton gweb))
+(put 'g 'custom-loads '(g-auth g-utils gfeeds gmaps gskeleton gweb))
 (put 'g-auth 'custom-loads '(g-auth))
-(put 'gblogger 'custom-loads '(gblogger))
-(put 'gdocs 'custom-loads '(gdocs))
 (put 'gfeeds 'custom-loads '(gfeeds))
 (put 'gmaps 'custom-loads '(gmaps))
-(put 'gphoto 'custom-loads '(gphoto))
 (put 'gskeleton 'custom-loads '(gskeleton))
 (put 'gweb 'custom-loads '(gmaps))
 
