@@ -1,4 +1,4 @@
-;;; mac-voices.el --- Define various device independent voices in terms of Mac tags
+;;; mac-voices.el --- Define various device independent voices in terms of Mac tags  -*- lexical-binding: t; -*-
 ;;; $Id: mac-voices.el 6342 2009-10-20 19:12:40Z tv.raman.tv $
 ;;; $Author: Dave $
 ;;; Description:  Module to set up Mac voices and personalities
@@ -349,7 +349,7 @@ and TABLE gives the values along that dimension."
 ;;}}}
 ;;{{{  punctuations
 
-(defsubst mac-get-punctuations-code (value)
+(defsubst mac-get-punctuations-code (_value)
   "Return string needed to set specified punctuations mode."
   "")
 
