@@ -1,4 +1,4 @@
-;;; xbacklight.el --- Control Display Brightness From Emacs
+;;; xbacklight.el --- Control Display Brightness From Emacs  -*- lexical-binding: t; -*-
 ;;;$Id$
 ;;;Emacs front-end to XBacklight
 ;;{{{  Copyright:
@@ -62,14 +62,17 @@
       (message "Brightness is %d" (round  (read value))))
      (t (message "Brightness is %s" value)))))
 
+;;; forward declaration:
+(defvar emacspeak-speak-messages)
+(defvar emacspeak-use-auditory-icons)
 ;;;###autoload
 (defun xbacklight-set (brightness)
   "Set brightness to  specified level.
 `brightness' is a percentage value."
   (interactive "nBrightness: ")
-  (let ((emacspeak-speak-messages nil))
-    (shell-command (format "%s -set %s"
-                           xbacklight-cmd brightness)))
+  (ems-with-messages-silenced
+   (shell-command (format "%s -set %s"
+                          xbacklight-cmd brightness)))
   (xbacklight-get))
 
 (defgroup xbacklight nil
@@ -85,17 +88,17 @@
 (defun xbacklight-increment ()
   "Increase brightness by  by one step."
   (interactive)
-  (let ((emacspeak-speak-messages nil))
-    (shell-command (format "%s -inc %s" xbacklight-cmd xbacklight-step))
-    (xbacklight-get))
+  (ems-with-messages-silenced
+   (shell-command (format "%s -inc %s" xbacklight-cmd xbacklight-step))
+   (xbacklight-get))
   (xbacklight-get))
 
 ;;;###autoload
 (defun xbacklight-decrement ()
   "Decrease brightness by  by one step."
   (interactive)
-  (let ((emacspeak-speak-messages nil))
-    (shell-command (format "%s -dec %s" xbacklight-cmd xbacklight-step)))
+  (ems-with-messages-silenced
+   (shell-command (format "%s -dec %s" xbacklight-cmd xbacklight-step)))
   (xbacklight-get))
 
 ;;;###autoload
